@@ -1,44 +1,30 @@
-from io import BytesIO
-
-from mitmproxy.utils import data
-from mitmproxy.net import tcp
-from mitmproxy.net import http
+from mitmproxy import http
 
 
-test_data = data.Data(__name__).push("../../test/")
-
-
-def treader(bytes):
-    """
-        Construct a tcp.Read object from bytes.
-    """
-    fp = BytesIO(bytes)
-    return tcp.Reader(fp)
-
-
-def treq(**kwargs):
+def treq(**kwargs) -> http.Request:
     """
     Returns:
         mitmproxy.net.http.Request
     """
     default = dict(
-        first_line_format="relative",
+        host="address",
+        port=22,
         method=b"GET",
         scheme=b"http",
-        host=b"address",
-        port=22,
+        authority=b"",
         path=b"/path",
         http_version=b"HTTP/1.1",
         headers=http.Headers(((b"header", b"qvalue"), (b"content-length", b"7"))),
         content=b"content",
+        trailers=None,
         timestamp_start=946681200,
         timestamp_end=946681201,
     )
     default.update(kwargs)
-    return http.Request(**default)
+    return http.Request(**default)  # type: ignore
 
 
-def tresp(**kwargs):
+def tresp(**kwargs) -> http.Response:
     """
     Returns:
         mitmproxy.net.http.Response
@@ -49,8 +35,9 @@ def tresp(**kwargs):
         reason=b"OK",
         headers=http.Headers(((b"header-response", b"svalue"), (b"content-length", b"7"))),
         content=b"message",
+        trailers=None,
         timestamp_start=946681202,
         timestamp_end=946681203,
     )
     default.update(kwargs)
-    return http.Response(**default)
+    return http.Response(**default)  # type: ignore
